@@ -44,6 +44,44 @@ def now_day(days_back: int = 0) -> str:
             datetime.timedelta(days=days_back)).strftime('%a')
 
 
+def get_day(ts: float) -> datetime.datetime:
+    """
+    Datetime object from a ts
+    :param ts: timestamp in s or ms
+    :return:
+    """
+    if ts > 5000000000:
+        ts /= 1000
+    return datetime.datetime.fromtimestamp(ts, tz=gettz(os.environ["TZ"]))
+
+
+def min_from_midnight(ts: float) -> float:
+    """
+    Minutes passed since midnight
+    :param ts:
+    :return:
+    """
+    return get_day(ts).hour * 60 + get_day(ts).minute
+
+
+def day_of_the_week(ts: float) -> str:
+    """
+    Returns day of the week for the ts
+    :param ts:
+    :return:
+    """
+    return get_day(ts).strftime("%a")
+
+
+def hour_of_ts(ts: float) -> int:
+    """
+    Returns the hour of the ts
+    :param ts:
+    :return:
+    """
+    return get_day(ts).hour
+
+
 def hour() -> int:
     """
     Returns the current hour
